from .directory_reader import *
from .file_handlers import *
from .file_filtering import *
from .content_utils import *
from .directory_reader import *
from .file_filtering import *
from .abstractFileImporter import *



ls = []
for each in """root      840376  2.7  1.4 1907836 1901656 ?     Ss   Nov08  61:36 /sbin/mount.ntfs /dev/sde2 /mnt/16T -o rw
root      965957  0.0  0.0  17144  6784 pts/30   T+   Nov09   0:00 sudo rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      965960  0.0  0.0  17144  2624 pts/32   Ss+  Nov09   0:00 sudo rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      965961  0.0  0.0  18920 12288 pts/32   T    Nov09   0:03 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      965962  0.0  0.0  18960 10468 pts/32   T    Nov09   0:03 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      965963  0.0  0.0 199292 28004 pts/32   T    Nov09   0:00 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966174  0.0  0.0  17152  6784 ?        S    Nov09   0:00 sudo rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966175  0.2  0.2 317172 296140 ?       S    Nov09   1:43 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966176  0.1  0.1 282840 258292 ?       S    Nov09   1:03 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966177  0.1  0.4 13632896 528844 ?     S    Nov09   1:22 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966187  0.0  0.0  17144  6656 pts/33   T+   Nov09   0:00 sudo rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966190  0.0  0.0  17144  2568 pts/35   Ss+  Nov09   0:00 sudo rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966191  0.0  0.0  19184 12168 pts/35   T    Nov09   0:01 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966192  0.0  0.0  17940  8932 pts/35   T    Nov09   0:00 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966193  0.0  0.0 199036 11436 pts/35   T    Nov09   0:00 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966286  0.0  0.0  17148  6784 ?        S    Nov09   0:00 sudo rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966287  0.2  0.2 316596 295244 ?       S    Nov09   1:39 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966288  0.1  0.1 282800 258008 ?       S    Nov09   1:01 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966289  0.1  0.4 13632868 537232 ?     S    Nov09   1:18 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966299  0.0  0.0  17144  6784 ?        S    Nov09   0:00 sudo rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966302  0.0  0.0  17144  2496 pts/38   Ss+  Nov09   0:00 sudo rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966303  0.2  0.2 316596 295412 pts/38  S    Nov09   1:37 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966304  0.1  0.1 282800 257688 pts/38  S    Nov09   1:01 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966305  0.1  0.4 13632868 535764 pts/38 S   Nov09   1:18 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966386  0.0  0.0  17144  6656 ?        S    Nov09   0:00 sudo rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966387  0.2  0.2 316600 295176 ?       S    Nov09   1:36 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966388  0.1  0.1 282800 257500 ?       S    Nov09   1:02 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966389  0.1  0.4 13632868 566340 ?     S    Nov09   1:17 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966457  0.0  0.0  17152  6656 ?        S    Nov09   0:00 sudo rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966460  0.0  0.0  17152  2500 pts/40   Ss+  Nov09   0:00 sudo rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966461  0.2  0.2 316600 295180 pts/40  S    Nov09   1:57 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966462  0.1  0.1 282800 257928 pts/40  S    Nov09   1:05 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
root      966463  0.1  0.4 13632868 570340 pts/40 S   Nov09   1:17 rsync -avh --ignore-existing --progress --exclude node_modules /mnt/16T/evo980-new/ /mnt/24T/wd_main_980/
""".split('\n'):
  if each:
    ls.append([ea for ea in each.split(' ') if ea][1])
input(' '.join(ls))



# file_reader.py

import os,glob
import fnmatch
from pathlib import Path
from typing import List, Optional, Set

from abstract_utilities import make_list,get_media_exts, is_media_type
def get_allowed(allowed=None):
    if allowed != False:
        if allowed == True:
            allowed = None
        allowed = allowed or make_allowed_predicate()
    else:
        def allowed(*args):
            return True
        allowed = allowed
    return allowed
def get_globs(items):
    glob_paths = []
    for item in make_list(items):
        pattern = os.path.join(item, "**/*")  # include all files recursively\n
        glob_paths += glob.glob(pattern, recursive=True)
    return glob_paths
def get_files(items,allowed=True):
    allowed = get_allowed(allowed=allowed)
    return [item for item in items if item and os.path.isfile(item) and allowed(item)]
def get_dirs(items,allowed=False):
    allowed = get_allowed(allowed=allowed)
    return [item for item in items if item and os.path.isdir(item) and allowed(item)]
def filter_files(items,allowed=None,files = []):
    allowed = get_allowed(allowed=allowed)
    glob_paths = get_globs(items)
    return [glob_path for glob_path in glob_paths if glob_path and os.path.isfile(glob_path) and glob_path not in files and allowed(glob_path)]
def filter_dirs(items,allowed=None,dirs = []):
    allowed = get_allowed(allowed=allowed)
    glob_paths = get_globs(items)
    return [glob_path for glob_path in glob_paths if glob_path and os.path.isdir(glob_path) and glob_path not in dirs and allowed(glob_path)]
def get_all_files(items,allowed=None):
    dirs = get_all_dirs(items)
    files = get_files(items)
    nu_files = []
    for directory in dirs:
        files += filter_files(directory,allowed=allowed,files=files)
    return files
def get_all_dirs(items,allowed=None):
    allowed = get_allowed(allowed=allowed)
    dirs = get_dirs(items)
    nu_dirs=[]
    for directory in dirs:
        nu_dirs += filter_dirs(directory,allowed=allowed,dirs=nu_dirs)
    return nu_dirs

# ─── 1) Build a predicate from user + defaults ──────────────────────────────

def get_default_modular(obj,default=None,add=False,typ=set):
    if obj in [False,True,None]:
        if obj in [True,None]:
            obj = default
        if obj == False:
            obj =None
    elif add == True:
        if typ == set:
            obj = typ(typ(obj) | typ(default))
        elif typ == list:
            obj = make_list(obj) + make_list(default
    return obj
def make_allowed_predicate(
    *,
    allowed_exts: Optional[Set[str]] = None,
    unallowed_exts: Optional[Set[str]] = None,
    exclude_types: Optional[Set[str]] = None,
    exclude_dirs: Optional[List[str]] = None,
    extra_patterns: Optional[List[str]] = None,
    add = False
) -> callable:
    allowed_exts = get_default_modular(allowed_exts,default=DEFAULT_ALLOWED_EXTS,add=add,typ=set)
    unallowed_exts = get_default_modular(unallowed_exts,default=DEFAULT_UNALLOWED_EXTS,add=add,typ=set)
    exclude_types = get_default_modular(exclude_types,default=DEFAULT_EXCLUDE_TYPES,add=add,typ=set)
    exclude_dirs = get_default_modular(exclude_dirs,default=DEFAULT_EXCLUDE_DIRS,add=add,typ=list)
    patterns_to_skip = get_default_modular(extra_patterns,default=DEFAULT_EXCLUDE_PATTERNS,add=add,typ=list)

    def allowed(path: str) -> bool:
        p = Path(path)
        name = p.name.lower()
        path_str = str(p).lower()
        # A) Skip directories by substring or pattern
        for dir_pattern in exclude_dirs:
            if p.is_dir() and (dir_pattern in path_str or fnmatch.fnmatch(name, dir_pattern.lower())):
                return False
        # B) Skip by filename pattern
        for pat in patterns_to_skip:
            if fnmatch.fnmatch(name, pat.lower()):
                return False
        # C) Skip by media category
        if p.is_file():
            ext = p.suffix.lower()
            if ext not in allowed_exts or ext in unallowed_exts:
                return False
        return True
    return allowed

def collect_filepaths(
    roots: List[str],
    *,
    allowed_exts: Set[str] = None,
    unallowed_exts: Set[str] = None,
    exclude_types: Set[str] = None,
    exclude_dirs: List[str] = None,
    exclude_file_patterns: List[str] = None,
) -> List[str]:
    allowed = make_allowed_predicate(
        allowed_exts=allowed_exts,
        unallowed_exts=unallowed_exts,
        exclude_types=exclude_types,
        exclude_dirs=exclude_dirs,
        extra_patterns=exclude_file_patterns
    )
    roots = make_list(roots or [])
    original_dirs = get_dirs(roots, allowed=allowed)
    original_globs = get_globs(original_dirs)
    files = get_files(original_globs, allowed=allowed)
    filtered_dirs = filter_dirs(original_dirs, allowed=allowed)
    for filtered_directory in filtered_dirs:
        files += filter_files(filtered_directory, allowed=allowed, files=files)
    return files
